@@ -2,10 +2,10 @@
 from photoshop import Session
 
 with Session() as ps:
-    psd_file = 'your/psd/save/file/path.psd'
+    psd_file = "your/psd/save/file/path.psd"
     doc = ps.active_document
     options = ps.PhotoshopSaveOptions()
     layers = doc.artLayers
     doc.saveAs(psd_file, options, True)
-    ps.alert('Task done!')
+    ps.alert("Task done!")
     ps.echo(doc.activeLayer)
