@@ -118,10 +118,12 @@ class Session:
         self.JPEGSaveOptions = JPEGSaveOptions
         self.PDFSaveOptions = PDFSaveOptions
         self.PNGSaveOptions = PNGSaveOptions
+        self.ElementPlacement = ElementPlacement
         self.PhotoshopSaveOptions = PhotoshopSaveOptions
         self.ExportOptionsSaveForWeb = ExportOptionsSaveForWeb
         self.BMPSaveOptions = BMPSaveOptions
         self.TiffSaveOptions = TiffSaveOptions
+        self.TargaSaveOptions = TargaSaveOptions
         self.LabColor = LabColor
         self.HSBColor = HSBColor
         self.CMYKColor = CMYKColor
@@ -184,7 +186,7 @@ class Session:
 
 
 __title__ = "photoshop_python_api"
-__version__ = "0.10.0"
+__version__ = "0.11.0"
 __author__ = "Long Hao"
 __license__ = "MIT"
 __copyright__ = "Copyright 2018 Long Hao"
