@@ -1,6 +1,6 @@
 from photoshop._core import Photoshop
-from photoshop._layerSet import LayerSet
 from photoshop.errors import PhotoshopPythonAPIError
+from photoshop._layerSet import LayerSet
 
 
 class LayerSets(Photoshop):
@@ -31,4 +31,5 @@ class LayerSets(Photoshop):
         for layer in self.app:
             if name == layer.name:
                 return LayerSet(layer)
-        raise PhotoshopPythonAPIError(f"Could not find a LayerSet named " f'"{name}"')
+        raise PhotoshopPythonAPIError("Could not find a LayerSet named "
+                                      f'"{name}"')
