@@ -1,11 +1,13 @@
 from photoshop.colors.cmyk import CMYKColor
+from photoshop.colors.gray import GrayColor
 from photoshop.colors.hsb import HSBColor
 from photoshop.colors.lab import LabColor
 from photoshop.colors.rgb import RGBColor
 
 __all__ = [
-    'LabColor',
-    'RGBColor',
-    'CMYKColor',
-    'HSBColor',
+    "CMYKColor",
+    "HSBColor",
+    "LabColor",
+    "RGBColor",
+    "GrayColor",
 ]
